Method: Shotstack::EditApi#put_template

Defined in:
lib/shotstack/api/edit_api.rb

#put_template(id, template, opts = {}) ⇒ TemplateResponse

Update Template Update an existing template by template id. **Base URL:** api.shotstack.io/version

Parameters:

  • The id of the template in UUID format

  • Update an individual templates name and [Edit](#tocs_edit). Both template name and template must be provided. If the template parameter is omitted a blank template will be saved.

  • (defaults to: {})

    the optional parameters

Returns:



560
561
562
563
# File 'lib/shotstack/api/edit_api.rb', line 560

def put_template(id, template, opts = {})
  data, _status_code, _headers = put_template_with_http_info(id, template, opts)
  data
end