Method: Shotstack::AudioAsset#speed

Defined in:
lib/shotstack/models/audio_asset.rb

#speedObject

Adjust the playback speed of the audio clip between 0 (paused) and 10 (10x normal speed), where 1 is normal speed (defaults to 1). Adjusting the speed will also adjust the duration of the clip and may require you to adjust the Clip length. For example, if you set speed to 0.5, the clip will need to be 2x as long to play the entire audio (i.e. original length / 0.5). If you set speed to 2, the clip will need to be half as long to play the entire audio (i.e. original length / 2).



32
33
34
# File 'lib/shotstack/models/audio_asset.rb', line 32

def speed
  @speed
end