Class: Shotstack::HtmlAsset

Inherits:
Asset
  • Object
show all
Defined in:
lib/shotstack/models/html_asset.rb

Overview

The HtmlAsset clip type lets you create text based layout and formatting using HTML and CSS. You can also set the height and width of a bounding box for the HTML content to sit within. Text and elements will wrap within the bounding box.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HtmlAsset

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/shotstack/models/html_asset.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shotstack::HtmlAsset` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shotstack::HtmlAsset`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'html'
  end

  if attributes.key?(:'html')
    self.html = attributes[:'html']
  end

  if attributes.key?(:'css')
    self.css = attributes[:'css']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.key?(:'background')
    self.background = attributes[:'background']
  else
    self.background = 'transparent'
  end

  if attributes.key?(:'position')
    self.position = attributes[:'position']
  else
    self.position = 'center'
  end
end

Instance Attribute Details

#backgroundObject

Apply a background color behind the HTML bounding box using. Set the text color using hexadecimal color notation. Transparency is supported by setting the first two characters of the hex string (opposite to HTML), i.e. #80ffffff will be white with 50% transparency.



35
36
37
# File 'lib/shotstack/models/html_asset.rb', line 35

def background
  @background
end

#cssObject

The CSS text string to apply styling to the HTML.



26
27
28
# File 'lib/shotstack/models/html_asset.rb', line 26

def css
  @css
end

#heightObject

Set the width of the HTML asset bounding box. Text and elements will be masked if they exceed the height of the bounding box.



32
33
34
# File 'lib/shotstack/models/html_asset.rb', line 32

def height
  @height
end

#htmlObject

The HTML text string.



23
24
25
# File 'lib/shotstack/models/html_asset.rb', line 23

def html
  @html
end

#positionObject

Place the HTML in one of nine predefined positions within the HTML area. <ul> <li>top - top (center)</li> <li>topRight - top right</li> <li>right - right (center)</li> <li>bottomRight - bottom right</li> <li>bottom - bottom (center)</li> <li>bottomLeft - bottom left</li> <li>left - left (center)</li> <li>topLeft - top left</li> <li>center - center</li> </ul>



38
39
40
# File 'lib/shotstack/models/html_asset.rb', line 38

def position
  @position
end

#typeObject

The type of asset - set to html for HTML.



20
21
22
# File 'lib/shotstack/models/html_asset.rb', line 20

def type
  @type
end

#widthObject

Set the width of the HTML asset bounding box. Text will wrap to fill the bounding box.



29
30
31
# File 'lib/shotstack/models/html_asset.rb', line 29

def width
  @width
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/shotstack/models/html_asset.rb', line 63

def self.attribute_map
  {
    :'type' => :'type',
    :'html' => :'html',
    :'css' => :'css',
    :'width' => :'width',
    :'height' => :'height',
    :'background' => :'background',
    :'position' => :'position'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
# File 'lib/shotstack/models/html_asset.rb', line 208

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/shotstack/models/html_asset.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
# File 'lib/shotstack/models/html_asset.rb', line 76

def self.openapi_types
  {
    :'type' => :'String',
    :'html' => :'String',
    :'css' => :'String',
    :'width' => :'Float',
    :'height' => :'Float',
    :'background' => :'String',
    :'position' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
189
190
191
# File 'lib/shotstack/models/html_asset.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      html == o.html &&
      css == o.css &&
      width == o.width &&
      height == o.height &&
      background == o.background &&
      position == o.position
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/shotstack/models/html_asset.rb', line 236

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    Shotstack.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/shotstack/models/html_asset.rb', line 305

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/shotstack/models/html_asset.rb', line 215

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/shotstack/models/html_asset.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/shotstack/models/html_asset.rb', line 201

def hash
  [type, html, css, width, height, background, position].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/shotstack/models/html_asset.rb', line 146

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @html.nil?
    invalid_properties.push('invalid value for "html", html cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



281
282
283
# File 'lib/shotstack/models/html_asset.rb', line 281

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/shotstack/models/html_asset.rb', line 287

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



275
276
277
# File 'lib/shotstack/models/html_asset.rb', line 275

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



161
162
163
164
165
166
167
# File 'lib/shotstack/models/html_asset.rb', line 161

def valid?
  return false if @type.nil?
  return false if @html.nil?
  position_validator = EnumAttributeValidator.new('String', ["top", "topRight", "right", "bottomRight", "bottom", "bottomLeft", "left", "topLeft", "center"])
  return false unless position_validator.valid?(@position)
  true
end