Method: Shotstack::Output#scale_to

Defined in:
lib/shotstack/models/output.rb

#scale_toObject

Override the resolution and scale the video or image to render at a different size. When using scaleTo the asset should be edited at the resolution dimensions, i.e. use font sizes that look best at HD, then use scaleTo to output the file at SD and the text will be scaled to the correct size. This is useful if you want to create multiple asset sizes. <ul> <li>preview - 512px x 288px @ 15fps</li> <li>mobile - 640px x 360px @ 25fps</li> <li>sd - 1024px x 576px @25fps</li> <li>hd - 1280px x 720px @25fps</li> <li>1080 - 1920px x 1080px @25fps</li> </ul>



34
35
36
# File 'lib/shotstack/models/output.rb', line 34

def scale_to
  @scale_to
end