Class: Shotstack::RenderApi

Inherits:
Object
  • Object
show all
Defined in:
lib/shotstack/api/render_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RenderApi

Returns a new instance of RenderApi.



7
8
9
# File 'lib/shotstack/api/render_api.rb', line 7

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



5
6
7
# File 'lib/shotstack/api/render_api.rb', line 5

def api_client
  @api_client
end

Instance Method Details

#get_render(id, opts = {}) ⇒ RenderResponse

Get the rendering status and details of a timeline by ID.

Parameters:

  • id

    The id of the timeline render task in UUID format

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



77
78
79
80
# File 'lib/shotstack/api/render_api.rb', line 77

def get_render(id, opts = {})
  data, status_code, headers = get_render_with_http_info(id, opts)
  return data
end

#get_render_with_http_info(id, opts = {}) ⇒ Array<(RenderResponse, Fixnum, Hash)>

Get the rendering status and details of a timeline by ID.

Parameters:

  • id

    The id of the timeline render task in UUID format

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RenderResponse, Fixnum, Hash)>)

    RenderResponse data, response status code and response headers



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/shotstack/api/render_api.rb', line 87

def get_render_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RenderApi#get_render ..."
  end
  
  # verify the required parameter 'id' is set
  fail "Missing the required parameter 'id' when calling get_render" if id.nil?
  
  # resource path
  path = "/render/{id}".sub('{format}','json').sub('{' + 'id' + '}', id.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  _header_accept = ['application/json']
  _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

  # HTTP header 'Content-Type'
  _header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  

  auth_names = ['DeveloperKey']
  data, status_code, headers = @api_client.call_api(:GET, path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'RenderResponse')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#get_render\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_render(edit, opts = {}) ⇒ QueuedResponse

Render the contents of a timeline as a video file.

Parameters:

  • edit

    Edit

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



16
17
18
19
# File 'lib/shotstack/api/render_api.rb', line 16

def post_render(edit, opts = {})
  data, status_code, headers = post_render_with_http_info(edit, opts)
  return data
end

#post_render_with_http_info(edit, opts = {}) ⇒ Array<(QueuedResponse, Fixnum, Hash)>

Render the contents of a timeline as a video file.

Parameters:

  • edit

    Edit

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(QueuedResponse, Fixnum, Hash)>)

    QueuedResponse data, response status code and response headers



26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/shotstack/api/render_api.rb', line 26

def post_render_with_http_info(edit, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug "Calling API: RenderApi#post_render ..."
  end
  
  # verify the required parameter 'edit' is set
  fail "Missing the required parameter 'edit' when calling post_render" if edit.nil?
  
  # resource path
  path = "/render".sub('{format}','json')

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}

  # HTTP header 'Accept' (if needed)
  _header_accept = ['application/json']
  _header_accept_result = @api_client.select_header_accept(_header_accept) and header_params['Accept'] = _header_accept_result

  # HTTP header 'Content-Type'
  _header_content_type = []
  header_params['Content-Type'] = @api_client.select_header_content_type(_header_content_type)

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(edit)
  

  auth_names = ['DeveloperKey']
  data, status_code, headers = @api_client.call_api(:POST, path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'QueuedResponse')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RenderApi#post_render\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end