Module: Shotstack
- Defined in:
- lib/shotstack/version.rb,
lib/shotstack.rb,
lib/shotstack/api_error.rb,
lib/shotstack/api_client.rb,
lib/shotstack/models/clip.rb,
lib/shotstack/models/crop.rb,
lib/shotstack/models/edit.rb,
lib/shotstack/models/font.rb,
lib/shotstack/models/size.rb,
lib/shotstack/api/edit_api.rb,
lib/shotstack/models/asset.rb,
lib/shotstack/models/range.rb,
lib/shotstack/models/track.rb,
lib/shotstack/api/serve_api.rb,
lib/shotstack/configuration.rb,
lib/shotstack/models/offset.rb,
lib/shotstack/models/output.rb,
lib/shotstack/models/poster.rb,
lib/shotstack/models/template.rb,
lib/shotstack/models/timeline.rb,
lib/shotstack/models/thumbnail.rb,
lib/shotstack/models/html_asset.rb,
lib/shotstack/models/luma_asset.rb,
lib/shotstack/models/soundtrack.rb,
lib/shotstack/models/transition.rb,
lib/shotstack/models/audio_asset.rb,
lib/shotstack/models/image_asset.rb,
lib/shotstack/models/merge_field.rb,
lib/shotstack/models/title_asset.rb,
lib/shotstack/models/video_asset.rb,
lib/shotstack/models/destinations.rb,
lib/shotstack/models/asset_response.rb,
lib/shotstack/models/probe_response.rb,
lib/shotstack/models/transformation.rb,
lib/shotstack/models/mux_destination.rb,
lib/shotstack/models/queued_response.rb,
lib/shotstack/models/render_response.rb,
lib/shotstack/models/template_render.rb,
lib/shotstack/models/template_response.rb,
lib/shotstack/models/asset_response_data.rb,
lib/shotstack/models/flip_transformation.rb,
lib/shotstack/models/skew_transformation.rb,
lib/shotstack/models/queued_response_data.rb,
lib/shotstack/models/render_response_data.rb,
lib/shotstack/models/asset_render_response.rb,
lib/shotstack/models/rotate_transformation.rb,
lib/shotstack/models/shotstack_destination.rb,
lib/shotstack/models/template_data_response.rb,
lib/shotstack/models/template_list_response.rb,
lib/shotstack/models/template_response_data.rb,
lib/shotstack/models/mux_destination_options.rb,
lib/shotstack/models/asset_response_attributes.rb,
lib/shotstack/models/template_data_response_data.rb,
lib/shotstack/models/template_list_response_data.rb,
lib/shotstack/models/template_list_response_item.rb
Overview
#Shotstack
#Shotstack is a video, image and audio editing service that allows for the automated generation of videos, images and audio using JSON and a RESTful API. You arrange and configure an edit and POST it to the API which will render your media and provide a file location when complete. For more details visit shotstack.io or checkout our getting started documentation. There are two main API's, one for editing and generating assets (Edit API) and one for managing hosted assets (Serve API). The Edit API base URL is: https://api.shotstack.io/version The Serve API base URL is: https://api.shotstack.io/serve/version
The version of the OpenAPI document: v1
Generated by: https://openapi-generator.tech OpenAPI Generator version: 5.4.0
Defined Under Namespace
Modules: Asset Classes: ApiClient, ApiError, AssetRenderResponse, AssetResponse, AssetResponseAttributes, AssetResponseData, AudioAsset, Clip, Configuration, Crop, Destinations, Edit, EditApi, FlipTransformation, Font, HtmlAsset, ImageAsset, LumaAsset, MergeField, MuxDestination, MuxDestinationOptions, Offset, Output, Poster, ProbeResponse, QueuedResponse, QueuedResponseData, Range, RenderResponse, RenderResponseData, RotateTransformation, ServeApi, ShotstackDestination, Size, SkewTransformation, Soundtrack, Template, TemplateDataResponse, TemplateDataResponseData, TemplateListResponse, TemplateListResponseData, TemplateListResponseItem, TemplateRender, TemplateResponse, TemplateResponseData, Thumbnail, Timeline, TitleAsset, Track, Transformation, Transition, VideoAsset
Constant Summary collapse
- VERSION =
'0.2.1'
Class Method Summary collapse
-
.configure ⇒ Object
Customize default settings for the SDK using block.
Class Method Details
.configure ⇒ Object
Customize default settings for the SDK using block. Shotstack.configure do |config| config.username = "xxx" config.password = "xxx" end If no block given, return the default Configuration object.
81 82 83 84 85 86 87 |
# File 'lib/shotstack.rb', line 81 def configure if block_given? yield(Configuration.default) else Configuration.default end end |