Module: Shotstack

Defined in:
lib/shotstack/version.rb,
lib/shotstack.rb,
lib/shotstack/api_error.rb,
lib/shotstack/api_client.rb,
lib/shotstack/models/clip.rb,
lib/shotstack/models/crop.rb,
lib/shotstack/models/edit.rb,
lib/shotstack/models/font.rb,
lib/shotstack/models/asset.rb,
lib/shotstack/models/range.rb,
lib/shotstack/models/track.rb,
lib/shotstack/configuration.rb,
lib/shotstack/models/offset.rb,
lib/shotstack/models/output.rb,
lib/shotstack/models/poster.rb,
lib/shotstack/models/timeline.rb,
lib/shotstack/models/thumbnail.rb,
lib/shotstack/api/endpoints_api.rb,
lib/shotstack/models/html_asset.rb,
lib/shotstack/models/luma_asset.rb,
lib/shotstack/models/soundtrack.rb,
lib/shotstack/models/transition.rb,
lib/shotstack/models/audio_asset.rb,
lib/shotstack/models/image_asset.rb,
lib/shotstack/models/title_asset.rb,
lib/shotstack/models/video_asset.rb,
lib/shotstack/models/queued_response.rb,
lib/shotstack/models/render_response.rb,
lib/shotstack/models/queued_response_data.rb,
lib/shotstack/models/render_response_data.rb

Overview

#Shotstack

#The Shotstack API is a video editing service that allows for the automated creation of videos using JSON. You can configure an edit and POST it to the Shotstack API which will render your video and provide a file location when complete. For more details visit [shotstack.io](shotstack.io) or checkout our [getting started](shotstack.gitbook.io/docs/guides/getting-started) documentation.

The version of the OpenAPI document: v1

Generated by: openapi-generator.tech OpenAPI Generator version: 5.0.0

Defined Under Namespace

Classes: ApiClient, ApiError, Asset, AudioAsset, Clip, Configuration, Crop, Edit, EndpointsApi, Font, HtmlAsset, ImageAsset, LumaAsset, Offset, Output, Poster, QueuedResponse, QueuedResponseData, Range, RenderResponse, RenderResponseData, Soundtrack, Thumbnail, Timeline, TitleAsset, Track, Transition, VideoAsset

Constant Summary collapse

VERSION =
'0.1.7'

Class Method Summary collapse

Class Method Details

.configureObject

Customize default settings for the SDK using block.

Shotstack.configure do |config|
  config.username = "xxx"
  config.password = "xxx"
end

If no block given, return the default Configuration object.



55
56
57
58
59
60
61
# File 'lib/shotstack.rb', line 55

def configure
  if block_given?
    yield(Configuration.default)
  else
    Configuration.default
  end
end