Class: Shotstack::Clip
- Inherits:
-
Object
- Object
- Shotstack::Clip
- Defined in:
- lib/shotstack/models/clip.rb
Overview
A clip is a container for a specific type of asset, i.e. a title, image, video, audio or html. You use a Clip to define when an asset will display on the timeline, how long it will play for and transitions, filters and effects to apply to it.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#asset ⇒ Object
The type of asset to display for the duration of this Clip.
-
#effect ⇒ Object
A motion effect to apply to the Clip.
-
#filter ⇒ Object
A filter effect to apply to the Clip.
-
#fit ⇒ Object
Set how the asset should be scaled to fit the viewport using one of the following options: <ul> <li>
cover- stretch the asset to fill the viewport without maintaining the aspect ratio.</li> <li>contain- fit the entire asset within the viewport while maintaining the original aspect ratio.</li> <li>crop- scale the asset to fill the viewport while maintaining the aspect ratio. -
#length ⇒ Object
The length, in seconds, the Clip should play for.
-
#offset ⇒ Object
Returns the value of attribute offset.
-
#opacity ⇒ Object
Sets the opacity of the Clip where 1 is opaque and 0 is transparent.
-
#position ⇒ Object
Place the asset in one of nine predefined positions of the viewport.
-
#scale ⇒ Object
Scale the asset to a fraction of the viewport size - i.e.
-
#start ⇒ Object
The start position of the Clip on the timeline, in seconds.
-
#transform ⇒ Object
Returns the value of attribute transform.
-
#transition ⇒ Object
Returns the value of attribute transition.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Clip
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Clip
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/shotstack/models/clip.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shotstack::Clip` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shotstack::Clip`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'asset') self.asset = attributes[:'asset'] end if attributes.key?(:'start') self.start = attributes[:'start'] end if attributes.key?(:'length') self.length = attributes[:'length'] end if attributes.key?(:'fit') self.fit = attributes[:'fit'] else self.fit = 'crop' end if attributes.key?(:'scale') self.scale = attributes[:'scale'] end if attributes.key?(:'position') self.position = attributes[:'position'] else self.position = 'center' end if attributes.key?(:'offset') self.offset = attributes[:'offset'] end if attributes.key?(:'transition') self.transition = attributes[:'transition'] end if attributes.key?(:'effect') self.effect = attributes[:'effect'] end if attributes.key?(:'filter') self.filter = attributes[:'filter'] end if attributes.key?(:'opacity') self.opacity = attributes[:'opacity'] else self.opacity = 1 end if attributes.key?(:'transform') self.transform = attributes[:'transform'] end end |
Instance Attribute Details
#asset ⇒ Object
The type of asset to display for the duration of this Clip. Value must be one of: <ul> <li><a href="#tocs_videoasset">VideoAsset</a></li> <li><a href="#tocs_imageasset">ImageAsset</a></li> <li><a href="#tocs_titleasset">TitleAsset</a></li> <li><a href="#tocs_htmlasset">HtmlAsset</a></li> <li><a href="#tocs_audioasset">AudioAsset</a></li> <li><a href="#tocs_lumaasset">LumaAsset</a></li> </ul>
20 21 22 |
# File 'lib/shotstack/models/clip.rb', line 20 def asset @asset end |
#effect ⇒ Object
A motion effect to apply to the Clip. <ul> <li>zoomIn - slow zoom in</li> <li>zoomOut - slow zoom out</li> <li>slideLeft - slow slide (pan) left</li> <li>slideRight - slow slide (pan) right</li> <li>slideUp - slow slide (pan) up</li> <li>slideDown - slow slide (pan) down</li> </ul>
42 43 44 |
# File 'lib/shotstack/models/clip.rb', line 42 def effect @effect end |
#filter ⇒ Object
A filter effect to apply to the Clip. <ul> <li>boost - boost contrast and saturation</li> <li>contrast - increase contrast</li> <li>darken - darken the scene</li> <li>greyscale - remove colour</li> <li>lighten - lighten the scene</li> <li>muted - reduce saturation and contrast</li> <li>invert - invert colors</li> </ul>
45 46 47 |
# File 'lib/shotstack/models/clip.rb', line 45 def filter @filter end |
#fit ⇒ Object
Set how the asset should be scaled to fit the viewport using one of the following options: <ul> <li>cover - stretch the asset to fill the viewport without maintaining the aspect ratio.</li> <li>contain - fit the entire asset within the viewport while maintaining the original aspect ratio.</li> <li>crop - scale the asset to fill the viewport while maintaining the aspect ratio. The asset will be cropped if it exceeds the bounds of the viewport.</li> <li>none - preserves the original asset dimensions and does not apply any scaling.</li> </ul>
29 30 31 |
# File 'lib/shotstack/models/clip.rb', line 29 def fit @fit end |
#length ⇒ Object
The length, in seconds, the Clip should play for.
26 27 28 |
# File 'lib/shotstack/models/clip.rb', line 26 def length @length end |
#offset ⇒ Object
Returns the value of attribute offset.
37 38 39 |
# File 'lib/shotstack/models/clip.rb', line 37 def offset @offset end |
#opacity ⇒ Object
Sets the opacity of the Clip where 1 is opaque and 0 is transparent.
48 49 50 |
# File 'lib/shotstack/models/clip.rb', line 48 def opacity @opacity end |
#position ⇒ Object
Place the asset in one of nine predefined positions of the viewport. This is most effective for when the asset is scaled and you want to position the element to a specific position. <ul> <li>top - top (center)</li> <li>topRight - top right</li> <li>right - right (center)</li> <li>bottomRight - bottom right</li> <li>bottom - bottom (center)</li> <li>bottomLeft - bottom left</li> <li>left - left (center)</li> <li>topLeft - top left</li> <li>center - center</li> </ul>
35 36 37 |
# File 'lib/shotstack/models/clip.rb', line 35 def position @position end |
#scale ⇒ Object
Scale the asset to a fraction of the viewport size - i.e. setting the scale to 0.5 will scale asset to half the size of the viewport. This is useful for picture-in-picture video and scaling images such as logos and watermarks.
32 33 34 |
# File 'lib/shotstack/models/clip.rb', line 32 def scale @scale end |
#start ⇒ Object
The start position of the Clip on the timeline, in seconds.
23 24 25 |
# File 'lib/shotstack/models/clip.rb', line 23 def start @start end |
#transform ⇒ Object
Returns the value of attribute transform.
50 51 52 |
# File 'lib/shotstack/models/clip.rb', line 50 def transform @transform end |
#transition ⇒ Object
Returns the value of attribute transition.
39 40 41 |
# File 'lib/shotstack/models/clip.rb', line 39 def transition @transition end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/shotstack/models/clip.rb', line 93 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/shotstack/models/clip.rb', line 75 def self.attribute_map { :'asset' => :'asset', :'start' => :'start', :'length' => :'length', :'fit' => :'fit', :'scale' => :'scale', :'position' => :'position', :'offset' => :'offset', :'transition' => :'transition', :'effect' => :'effect', :'filter' => :'filter', :'opacity' => :'opacity', :'transform' => :'transform' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 |
# File 'lib/shotstack/models/clip.rb', line 301 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 |
# File 'lib/shotstack/models/clip.rb', line 116 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/shotstack/models/clip.rb', line 98 def self.openapi_types { :'asset' => :'Asset', :'start' => :'Float', :'length' => :'Float', :'fit' => :'String', :'scale' => :'Float', :'position' => :'String', :'offset' => :'Offset', :'transition' => :'Transition', :'effect' => :'String', :'filter' => :'String', :'opacity' => :'Float', :'transform' => :'Transformation' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/shotstack/models/clip.rb', line 269 def ==(o) return true if self.equal?(o) self.class == o.class && asset == o.asset && start == o.start && length == o.length && fit == o.fit && scale == o.scale && position == o.position && offset == o.offset && transition == o.transition && effect == o.effect && filter == o.filter && opacity == o.opacity && transform == o.transform end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/shotstack/models/clip.rb', line 331 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Shotstack.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/shotstack/models/clip.rb', line 402 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/shotstack/models/clip.rb', line 308 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
288 289 290 |
# File 'lib/shotstack/models/clip.rb', line 288 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
294 295 296 |
# File 'lib/shotstack/models/clip.rb', line 294 def hash [asset, start, length, fit, scale, position, offset, transition, effect, filter, opacity, transform].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/shotstack/models/clip.rb', line 193 def list_invalid_properties invalid_properties = Array.new if @asset.nil? invalid_properties.push('invalid value for "asset", asset cannot be nil.') end if @start.nil? invalid_properties.push('invalid value for "start", start cannot be nil.') end if @length.nil? invalid_properties.push('invalid value for "length", length cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
378 379 380 |
# File 'lib/shotstack/models/clip.rb', line 378 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/shotstack/models/clip.rb', line 384 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
372 373 374 |
# File 'lib/shotstack/models/clip.rb', line 372 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/shotstack/models/clip.rb', line 212 def valid? return false if @asset.nil? return false if @start.nil? return false if @length.nil? fit_validator = EnumAttributeValidator.new('String', ["cover", "contain", "crop", "none"]) return false unless fit_validator.valid?(@fit) position_validator = EnumAttributeValidator.new('String', ["top", "topRight", "right", "bottomRight", "bottom", "bottomLeft", "left", "topLeft", "center"]) return false unless position_validator.valid?(@position) effect_validator = EnumAttributeValidator.new('String', ["zoomIn", "zoomOut", "slideLeft", "slideRight", "slideUp", "slideDown"]) return false unless effect_validator.valid?(@effect) filter_validator = EnumAttributeValidator.new('String', ["boost", "contrast", "darken", "greyscale", "lighten", "muted", "negative"]) return false unless filter_validator.valid?(@filter) true end |