Class: Shotstack::EndpointsApi
- Inherits:
-
Object
- Object
- Shotstack::EndpointsApi
- Defined in:
- lib/shotstack/api/endpoints_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_render(id, opts = {}) ⇒ RenderResponse
Get the rendering status, video url and details of a timeline by ID.
-
#get_render_with_http_info(id, opts = {}) ⇒ Array<(RenderResponse, Integer, Hash)>
Get the rendering status, video url and details of a timeline by ID.
-
#initialize(api_client = ApiClient.default) ⇒ EndpointsApi
constructor
A new instance of EndpointsApi.
-
#post_render(edit, opts = {}) ⇒ QueuedResponse
Render the contents of a timeline as a video file.
-
#post_render_with_http_info(edit, opts = {}) ⇒ Array<(QueuedResponse, Integer, Hash)>
Render the contents of a timeline as a video file.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ EndpointsApi
Returns a new instance of EndpointsApi.
19 20 21 |
# File 'lib/shotstack/api/endpoints_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/shotstack/api/endpoints_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_render(id, opts = {}) ⇒ RenderResponse
Get the rendering status, video url and details of a timeline by ID.
26 27 28 29 |
# File 'lib/shotstack/api/endpoints_api.rb', line 26 def get_render(id, opts = {}) data, _status_code, _headers = get_render_with_http_info(id, opts) data end |
#get_render_with_http_info(id, opts = {}) ⇒ Array<(RenderResponse, Integer, Hash)>
Get the rendering status, video url and details of a timeline by ID.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/shotstack/api/endpoints_api.rb', line 35 def get_render_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EndpointsApi.get_render ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling EndpointsApi.get_render" end pattern = Regexp.new(/^[0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12}$/) if @api_client.config.client_side_validation && id !~ pattern fail ArgumentError, "invalid value for 'id' when calling EndpointsApi.get_render, must conform to the pattern #{pattern}." end # resource path local_var_path = '/render/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'RenderResponse' # auth_names auth_names = opts[:auth_names] || ['DeveloperKey'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EndpointsApi#get_render\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_render(edit, opts = {}) ⇒ QueuedResponse
Render the contents of a timeline as a video file.
91 92 93 94 |
# File 'lib/shotstack/api/endpoints_api.rb', line 91 def post_render(edit, opts = {}) data, _status_code, _headers = post_render_with_http_info(edit, opts) data end |
#post_render_with_http_info(edit, opts = {}) ⇒ Array<(QueuedResponse, Integer, Hash)>
Render the contents of a timeline as a video file.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/shotstack/api/endpoints_api.rb', line 100 def post_render_with_http_info(edit, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EndpointsApi.post_render ...' end # verify the required parameter 'edit' is set if @api_client.config.client_side_validation && edit.nil? fail ArgumentError, "Missing the required parameter 'edit' when calling EndpointsApi.post_render" end # resource path local_var_path = '/render' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(edit) # return_type return_type = opts[:return_type] || 'QueuedResponse' # auth_names auth_names = opts[:auth_names] || ['DeveloperKey'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EndpointsApi#post_render\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |