Class: Shotstack::Output

Inherits:
Object
  • Object
show all
Defined in:
lib/shotstack/models/output.rb

Overview

The output format, render range and type of media to generate.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Output

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/shotstack/models/output.rb', line 117

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Shotstack::Output` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Shotstack::Output`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'format')
    self.format = attributes[:'format']
  end

  if attributes.key?(:'resolution')
    self.resolution = attributes[:'resolution']
  end

  if attributes.key?(:'aspect_ratio')
    self.aspect_ratio = attributes[:'aspect_ratio']
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  end

  if attributes.key?(:'fps')
    self.fps = attributes[:'fps']
  else
    self.fps = 25
  end

  if attributes.key?(:'scale_to')
    self.scale_to = attributes[:'scale_to']
  end

  if attributes.key?(:'quality')
    self.quality = attributes[:'quality']
  else
    self.quality = 'medium'
  end

  if attributes.key?(:'range')
    self.range = attributes[:'range']
  end

  if attributes.key?(:'poster')
    self.poster = attributes[:'poster']
  end

  if attributes.key?(:'thumbnail')
    self.thumbnail = attributes[:'thumbnail']
  end

  if attributes.key?(:'destinations')
    if (value = attributes[:'destinations']).is_a?(Array)
      self.destinations = value
    end
  end
end

Instance Attribute Details

#aspect_ratioObject

The aspect ratio (shape) of the video or image. Useful for social media output formats. Options are: <ul> <li>16:9 - regular landscape/horizontal aspect ratio (default)</li> <li>9:16 - vertical/portrait aspect ratio</li> <li>1:1 - square aspect ratio</li> <li>4:5 - short vertical/portrait aspect ratio</li> <li>4:3 - legacy TV aspect ratio</li> </ul>



26
27
28
# File 'lib/shotstack/models/output.rb', line 26

def aspect_ratio
  @aspect_ratio
end

#destinationsObject

A destination is a location where output files can be sent to for serving or hosting. By default all rendered assets are automatically sent to the Shotstack hosting destination. [DestinationShotstack](/#tocs_shotstackdestination) is currently the only option with plans to add more in the future such as S3, YouTube, Vimeo and Mux. If you do not require hosting you can opt-out using the exclude property.



46
47
48
# File 'lib/shotstack/models/output.rb', line 46

def destinations
  @destinations
end

#formatObject

The output format and type of media file to generate. <ul> <li>mp4 - mp4 video file</li> <li>gif - animated gif</li> <li>jpg - jpg image file</li> <li>png - png image file</li> <li>bmp - bmp image file</li> <li>mp3 - mp3 audio file (audio only)</li> </ul>



20
21
22
# File 'lib/shotstack/models/output.rb', line 20

def format
  @format
end

#fpsObject

Override the default frames per second. Useful for when the source footage is recorded at 30fps, i.e. on mobile devices. Lower frame rates can be used to add cinematic quality (24fps) or to create smaller file size/faster render times or animated gifs (12 or 15fps). Default is 25fps. <ul> <li>12 - 12fps</li> <li>15 - 15fps</li> <li>24 - 24fps</li> <li>25 - 25fps</li> <li>30 - 30fps</li> </ul>



31
32
33
# File 'lib/shotstack/models/output.rb', line 31

def fps
  @fps
end

#posterObject

Returns the value of attribute poster.



41
42
43
# File 'lib/shotstack/models/output.rb', line 41

def poster
  @poster
end

#qualityObject

Adjust the output quality of the video, image or audio. Adjusting quality affects render speed, download speeds and storage requirements due to file size. The default medium provides the most optimized choice for all three factors. <ul> <li>low - slightly reduced quality, smaller file size</li> <li>medium - optimized quality, render speeds and file size</li> <li>high - slightly increased quality, larger file size</li> </ul>



37
38
39
# File 'lib/shotstack/models/output.rb', line 37

def quality
  @quality
end

#rangeObject

Returns the value of attribute range.



39
40
41
# File 'lib/shotstack/models/output.rb', line 39

def range
  @range
end

#resolutionObject

The output resolution of the video or image. <ul> <li>preview - 512px x 288px @ 15fps</li> <li>mobile - 640px x 360px @ 25fps</li> <li>sd - 1024px x 576px @ 25fps</li> <li>hd - 1280px x 720px @ 25fps</li> <li>1080 - 1920px x 1080px @ 25fps</li> </ul>



23
24
25
# File 'lib/shotstack/models/output.rb', line 23

def resolution
  @resolution
end

#scale_toObject

Override the resolution and scale the video or image to render at a different size. When using scaleTo the asset should be edited at the resolution dimensions, i.e. use font sizes that look best at HD, then use scaleTo to output the file at SD and the text will be scaled to the correct size. This is useful if you want to create multiple asset sizes. <ul> <li>preview - 512px x 288px @ 15fps</li> <li>mobile - 640px x 360px @ 25fps</li> <li>sd - 1024px x 576px @25fps</li> <li>hd - 1280px x 720px @25fps</li> <li>1080 - 1920px x 1080px @25fps</li> </ul>



34
35
36
# File 'lib/shotstack/models/output.rb', line 34

def scale_to
  @scale_to
end

#sizeObject

Returns the value of attribute size.



28
29
30
# File 'lib/shotstack/models/output.rb', line 28

def size
  @size
end

#thumbnailObject

Returns the value of attribute thumbnail.



43
44
45
# File 'lib/shotstack/models/output.rb', line 43

def thumbnail
  @thumbnail
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/shotstack/models/output.rb', line 88

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/shotstack/models/output.rb', line 71

def self.attribute_map
  {
    :'format' => :'format',
    :'resolution' => :'resolution',
    :'aspect_ratio' => :'aspectRatio',
    :'size' => :'size',
    :'fps' => :'fps',
    :'scale_to' => :'scaleTo',
    :'quality' => :'quality',
    :'range' => :'range',
    :'poster' => :'poster',
    :'thumbnail' => :'thumbnail',
    :'destinations' => :'destinations'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



304
305
306
# File 'lib/shotstack/models/output.rb', line 304

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



110
111
112
113
# File 'lib/shotstack/models/output.rb', line 110

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/shotstack/models/output.rb', line 93

def self.openapi_types
  {
    :'format' => :'String',
    :'resolution' => :'String',
    :'aspect_ratio' => :'String',
    :'size' => :'Size',
    :'fps' => :'Integer',
    :'scale_to' => :'String',
    :'quality' => :'String',
    :'range' => :'Range',
    :'poster' => :'Poster',
    :'thumbnail' => :'Thumbnail',
    :'destinations' => :'Array<Destinations>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/shotstack/models/output.rb', line 273

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      format == o.format &&
      resolution == o.resolution &&
      aspect_ratio == o.aspect_ratio &&
      size == o.size &&
      fps == o.fps &&
      scale_to == o.scale_to &&
      quality == o.quality &&
      range == o.range &&
      poster == o.poster &&
      thumbnail == o.thumbnail &&
      destinations == o.destinations
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/shotstack/models/output.rb', line 334

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Shotstack.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



405
406
407
408
409
410
411
412
413
414
415
416
417
# File 'lib/shotstack/models/output.rb', line 405

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/shotstack/models/output.rb', line 311

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


291
292
293
# File 'lib/shotstack/models/output.rb', line 291

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



297
298
299
# File 'lib/shotstack/models/output.rb', line 297

def hash
  [format, resolution, aspect_ratio, size, fps, scale_to, quality, range, poster, thumbnail, destinations].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
188
189
190
# File 'lib/shotstack/models/output.rb', line 183

def list_invalid_properties
  invalid_properties = Array.new
  if @format.nil?
    invalid_properties.push('invalid value for "format", format cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



381
382
383
# File 'lib/shotstack/models/output.rb', line 381

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/shotstack/models/output.rb', line 387

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



375
376
377
# File 'lib/shotstack/models/output.rb', line 375

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/shotstack/models/output.rb', line 194

def valid?
  return false if @format.nil?
  format_validator = EnumAttributeValidator.new('String', ["mp4", "gif", "mp3", "jpg", "png", "bmp"])
  return false unless format_validator.valid?(@format)
  resolution_validator = EnumAttributeValidator.new('String', ["preview", "mobile", "sd", "hd", "1080"])
  return false unless resolution_validator.valid?(@resolution)
  aspect_ratio_validator = EnumAttributeValidator.new('String', ["16:9", "9:16", "1:1", "4:5", "4:3"])
  return false unless aspect_ratio_validator.valid?(@aspect_ratio)
  fps_validator = EnumAttributeValidator.new('Integer', [12, 15, 24, 25, 30])
  return false unless fps_validator.valid?(@fps)
  scale_to_validator = EnumAttributeValidator.new('String', ["preview", "mobile", "sd", "hd", "1080"])
  return false unless scale_to_validator.valid?(@scale_to)
  quality_validator = EnumAttributeValidator.new('String', ["low", "medium", "high"])
  return false unless quality_validator.valid?(@quality)
  true
end