Class: Shotstack::Output
- Inherits:
-
Object
- Object
- Shotstack::Output
- Defined in:
- lib/shotstack/models/output.rb
Overview
The video output format.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#aspect_ratio ⇒ Object
The aspect ratio (shape) of the video.
-
#format ⇒ Object
mp4,webmvideo or animatedgif. -
#poster ⇒ Object
Returns the value of attribute poster.
-
#resolution ⇒ Object
The output resolution of the video.
-
#scale_to ⇒ Object
Override the resolution and scale the video to render at a different size.
-
#thumbnail ⇒ Object
Returns the value of attribute thumbnail.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Output
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Output
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/shotstack/models/output.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Shotstack::Output` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Shotstack::Output`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'format') self.format = attributes[:'format'] end if attributes.key?(:'resolution') self.resolution = attributes[:'resolution'] end if attributes.key?(:'aspect_ratio') self.aspect_ratio = attributes[:'aspect_ratio'] end if attributes.key?(:'scale_to') self.scale_to = attributes[:'scale_to'] end if attributes.key?(:'poster') self.poster = attributes[:'poster'] end if attributes.key?(:'thumbnail') self.thumbnail = attributes[:'thumbnail'] end end |
Instance Attribute Details
#aspect_ratio ⇒ Object
The aspect ratio (shape) of the video. Useful for social media sites. Options are: <ul> <li>16:9 - regular landscape/horizontal aspect ratio (default)</li> <li>9:16 - vertical/portrait aspect ratio.</li> <li>1:1 - square aspect ratio.</li> </ul>
25 26 27 |
# File 'lib/shotstack/models/output.rb', line 25 def aspect_ratio @aspect_ratio end |
#format ⇒ Object
mp4, webm video or animated gif
19 20 21 |
# File 'lib/shotstack/models/output.rb', line 19 def format @format end |
#poster ⇒ Object
Returns the value of attribute poster.
30 31 32 |
# File 'lib/shotstack/models/output.rb', line 30 def poster @poster end |
#resolution ⇒ Object
The output resolution of the video. <ul> <li>preview - 512px x 288px @ 15fps</li> <li>mobile - 640px x 360px @ 25fps</li> <li>sd - 1024px x 576px @ 25fps</li> <li>hd - 1280px x 720px @ 25fps</li> <li>1080 - 1920px x 1080px @ 25fps</li> </ul>
22 23 24 |
# File 'lib/shotstack/models/output.rb', line 22 def resolution @resolution end |
#scale_to ⇒ Object
Override the resolution and scale the video to render at a different size. When using scaleTo the video should be edited at the resolution dimensions, i.e. use font sizes that look best at HD, then use scaleTo to output the video at SD and the text will be scaled to the correct size. This is useful if you want to create multiple video sizes. <ul> <li>preview - 512px x 288px @ 15fps</li> <li>mobile - 640px x 360px @ 25fps</li> <li>sd - 1024px x 576px @25fps</li> <li>hd - 1280px x 720px @25fps</li> <li>1080 - 1920px x 1080px @25fps</li> </ul>
28 29 30 |
# File 'lib/shotstack/models/output.rb', line 28 def scale_to @scale_to end |
#thumbnail ⇒ Object
Returns the value of attribute thumbnail.
32 33 34 |
# File 'lib/shotstack/models/output.rb', line 32 def thumbnail @thumbnail end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/shotstack/models/output.rb', line 57 def self.attribute_map { :'format' => :'format', :'resolution' => :'resolution', :'aspect_ratio' => :'aspectRatio', :'scale_to' => :'scaleTo', :'poster' => :'poster', :'thumbnail' => :'thumbnail' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 |
# File 'lib/shotstack/models/output.rb', line 225 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/shotstack/models/output.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
69 70 71 72 73 74 75 76 77 78 |
# File 'lib/shotstack/models/output.rb', line 69 def self.openapi_types { :'format' => :'String', :'resolution' => :'String', :'aspect_ratio' => :'String', :'scale_to' => :'String', :'poster' => :'Poster', :'thumbnail' => :'Thumbnail' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 |
# File 'lib/shotstack/models/output.rb', line 199 def ==(o) return true if self.equal?(o) self.class == o.class && format == o.format && resolution == o.resolution && aspect_ratio == o.aspect_ratio && scale_to == o.scale_to && poster == o.poster && thumbnail == o.thumbnail end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/shotstack/models/output.rb', line 253 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model Shotstack.const_get(type).build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/shotstack/models/output.rb', line 322 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/shotstack/models/output.rb', line 232 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
212 213 214 |
# File 'lib/shotstack/models/output.rb', line 212 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/shotstack/models/output.rb', line 218 def hash [format, resolution, aspect_ratio, scale_to, poster, thumbnail].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/shotstack/models/output.rb', line 128 def list_invalid_properties invalid_properties = Array.new if @format.nil? invalid_properties.push('invalid value for "format", format cannot be nil.') end if @resolution.nil? invalid_properties.push('invalid value for "resolution", resolution cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
298 299 300 |
# File 'lib/shotstack/models/output.rb', line 298 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/shotstack/models/output.rb', line 304 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
292 293 294 |
# File 'lib/shotstack/models/output.rb', line 292 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/shotstack/models/output.rb', line 143 def valid? return false if @format.nil? format_validator = EnumAttributeValidator.new('String', ["mp4", "webm", "gif"]) return false unless format_validator.valid?(@format) return false if @resolution.nil? resolution_validator = EnumAttributeValidator.new('String', ["preview", "mobile", "sd", "hd", "1080"]) return false unless resolution_validator.valid?(@resolution) aspect_ratio_validator = EnumAttributeValidator.new('String', ["16:9", "9:16", "1:1"]) return false unless aspect_ratio_validator.valid?(@aspect_ratio) scale_to_validator = EnumAttributeValidator.new('String', ["preview", "mobile", "sd", "hd", "1080"]) return false unless scale_to_validator.valid?(@scale_to) true end |